@@ -9,6 +9,7 @@
  */
 namespace SebastianBergmann\CodeCoverage;
 
+use function array_fill;
 use SebastianBergmann\CodeCoverage\Driver\Driver;
 use SebastianBergmann\CodeCoverage\Driver\Selector;
 use SebastianBergmann\Environment\Runtime;
@@ -78,7 +79,7 @@ final class CodeCoverageTest extends TestCase
         $this->coverage->filter()->includeFile(TEST_FILES_PATH . 'BankAccount.php');
 
         $data = RawCodeCoverageData::fromXdebugWithoutPathCoverage([
-            TEST_FILES_PATH . 'BankAccount.php' => [
+            TEST_FILES_PATH . 'BankAccount.php'       => [
                 29 => -1,
                 31 => -1,
             ],
@@ -108,7 +109,6 @@ final class CodeCoverageTest extends TestCase
                 8  => [],
                 13 => [],
                 14 => [],
-                15 => [],
                 16 => [],
                 22 => [],
                 24 => [],
